summaryrefslogtreecommitdiff
path: root/src/mongo/client/sasl_client_authenticate.h
diff options
context:
space:
mode:
authorSpencer T Brody <spencer@10gen.com>2013-05-23 14:43:58 -0400
committerSpencer T Brody <spencer@10gen.com>2013-05-23 16:39:14 -0400
commit79c14ac356818963e3e12611dad032719de27e0f (patch)
tree0d3112cce3460d88009c7efedea2ebc155d406d4 /src/mongo/client/sasl_client_authenticate.h
parent454b52fc53c44b7b5be09ce51c140b501ef98a74 (diff)
downloadmongo-79c14ac356818963e3e12611dad032719de27e0f.tar.gz
Rename PrincipalName to UserName
Diffstat (limited to 'src/mongo/client/sasl_client_authenticate.h')
-rw-r--r--src/mongo/client/sasl_client_authenticate.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/mongo/client/sasl_client_authenticate.h b/src/mongo/client/sasl_client_authenticate.h
index c95cdc42660..621b0eaf3ef 100644
--- a/src/mongo/client/sasl_client_authenticate.h
+++ b/src/mongo/client/sasl_client_authenticate.h
@@ -40,9 +40,9 @@ namespace mongo {
* "autoAuthorize": Truthy values tell the server to automatically acquire privileges on
* all resources after successful authentication, which is the default. Falsey values
* instruct the server to await separate privilege-acquisition commands.
- * "user": The string name of the principal to authenticate.
+ * "user": The string name of the user to authenticate.
* "userSource": The database target of the auth command, which identifies the location
* of the credential information for the principal. May be "$external" if credential
* information is stored outside of the mongo cluster.
* "pwd": The password.
* "serviceName": The GSSAPI service name to use. Defaults to "mongodb".
@@ -77,7 +77,7 @@ namespace mongo {
extern const char* const saslContinueCommandName;
/// Name of the saslStart parameter indicating that the server should automatically grant the
/// connection all privileges associated with the principal after successful authentication.
extern const char* const saslCommandAutoAuthorizeFieldName;
/// Name of the field contain the status code in responses from the server.
@@ -107,13 +107,13 @@ namespace mongo {
/// Field containing sasl payloads passed to and from the server.
extern const char* const saslCommandPayloadFieldName;
/// Field containing the string identifier of the principal to authenticate in
/// saslClientAuthenticate().
- extern const char* const saslCommandPrincipalFieldName;
+ extern const char* const saslCommandUserFieldName;
/// Field containing the string identifier of the database containing credential information,
/// or "$external" if the credential information is stored outside of the mongo cluster.
- extern const char* const saslCommandPrincipalSourceFieldName;
+ extern const char* const saslCommandUserSourceFieldName;
/// Field overriding the FQDN of the hostname hosting the mongodb srevice in
/// saslClientAuthenticate().
@@ -40,9 +40,9 @@ namespace mongo {
* "userSource": The database target of the auth command, which identifies the location
- * of the credential information for the principal. May be "$external" if credential
+ * of the credential information for the user. May be "$external" if credential
* information is stored outside of the mongo cluster.
* "pwd": The password.
@@ -77,7 +77,7 @@ namespace mongo {
extern const char* const saslContinueCommandName;
/// Name of the saslStart parameter indicating that the server should automatically grant the
- /// connection all privileges associated with the principal after successful authentication.
+ /// connection all privileges associated with the user after successful authentication.
extern const char* const saslCommandAutoAuthorizeFieldName;
/// Name of the field contain the status code in responses from the server.
@@ -107,13 +107,13 @@ namespace mongo {
/// Field containing sasl payloads passed to and from the server.
extern const char* const saslCommandPayloadFieldName;
- /// Field containing the string identifier of the principal to authenticate in
+ /// Field containing the string identifier of the user to authenticate in
/// saslClientAuthenticate().